@@ -119,7 +119,7 @@ class RDFXMLHandler(handler.ContentHandler):
     def startPrefixMapping(self, prefix, namespace):
         self._ns_contexts.append(self._current_context.copy())
         self._current_context[namespace] = prefix
-        self.store.bind(prefix, URIRef(namespace), override=False)
+        self.store.bind(prefix, namespace or "", override=False)
 
     def endPrefixMapping(self, prefix):
         self._current_context = self._ns_contexts[-1]
@@ -323,6 +323,13 @@ class RDFXMLHandler(handler.ContentHandler):
         current.subject = subject
 
     def node_element_end(self, name, qname):
+        # repeat node-elements are only allowed
+        # at at top-level
+
+        if self.parent.object and self.current != self.stack[2]:
+
+            self.error("Repeat node-elements inside property elements: %s"%"".join(name))
+
         self.parent.object = self.current.subject
 
     def property_element_start(self, name, qname, attrs):
